@@ -174,7 +174,7 @@ class SlottedA_length(Base):
 
 
         # T=4
-        K1 = 100
+        K = 100
         [SAC, slots] = self.slotted_autocorrelation(magnitude, time, self.T, K1)
         SlottedA_length.SAC = SAC
         SlottedA_length.slots = slots
@@ -183,11 +183,11 @@ class SlottedA_length(Base):
         k = next((index for index, value in
                  enumerate(SAC2) if value < np.exp(-1)), None)
 
-        if k is None:
-            K2 = 200
+        while k is None:
+            K = K+K
             [SAC, slots] = self.slotted_autocorrelation(magnitude, time, self.T,
-                                                        K2, second_round=True,
-                                                        K1=K1)
+                                                    K, second_round=True,
+                                                    K1=K/2)
             SAC2 = SAC[slots]
             k = next((index for index, value in
                      enumerate(SAC2) if value < np.exp(-1)), None)
